<?php
/**
* 2016 Manel Alonso
*
* NOTICE OF LICENSE
*
* READ ATTACHED LICENSE.TXT
*
*  @author    Manel Alonso <alonso@byteamine.com>
*  @copyright 2016 Manel Alonso
*  @license   http://www.apache.org/licenses/LICENSE-2.0.txt Apache License 2.0
*/

if (!defined('_PS_VERSION_'))
	exit;

class MAproductQuantityPrice extends Module
{
	protected $config_form = false;

	public function __construct()
	{
		$this->name = 'maproductquantityprice';
		$this->tab = 'front_office_features';
		$this->version = '1.1.0';
		$this->author = 'Manel Alonso, alonso@byteamine.com';
		$this->need_instance = 0;
		$this->bootstrap = true;

		parent::__construct();

		$this->displayName = $this->l('MA Product Quantity Price FREE');
		$this->description = $this->l('Calculates in realtime the total amount when you change de quantity of a product. Please visit https://www.cubieez.com');
	}

	public function install()
	{
		$moneda_defecto = (int)Configuration::get('PS_CURRENCY_DEFAULT');
		$o_currency = new CurrencyCore($moneda_defecto);
		$simbolo = $o_currency->sign;

		Configuration::updateValue('PS_MAPQP_SIGN', $simbolo);
		$this->createFile();

		return parent::install() &&
		$this->registerHook('displayFooterProduct');
	}

	public function uninstall()
	{
		Configuration::deleteByName('PS_MAPQP_SIGN');
		return parent::uninstall();
	}

	public function getContent()
	{
		if (((bool)Tools::isSubmit('guardaOpciones')) == true) 
			$this->postProcess();

		$this->context->smarty->assign('module_dir', $this->_path);
		$output = $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure.tpl');

		return $output.$this->renderForm();
	}

	protected function renderForm()
	{
		$helper = new HelperForm();

		$helper->show_toolbar = false;
		$helper->table = $this->table;
		$helper->module = $this;
		$helper->default_form_language = $this->context->language->id;
		$helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

		$helper->identifier = $this->identifier;
		$helper->submit_action = 'guardaOpciones';
		$helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
		.'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
		$helper->token = Tools::getAdminTokenLite('AdminModules');

		$helper->tpl_vars = array(
		'fields_value' => $this->getConfigFormValues(),
		'languages' => $this->context->controller->getLanguages(),
		'id_language' => $this->context->language->id,
		);

		return $helper->generateForm(array($this->getConfigForm()));
	}

	protected function getConfigForm()
	{
		return array(
			'form' => array(
			'legend' => array(
				'title' => $this->l('Settings'),
				'icon' => 'icon-cogs',
			),
			'input' => array(
				array(
					'col' => 3,
					'type' => 'text',
					'prefix' => '<i class="fa fa-money"></i>',
					'desc' => $this->l('Enter the sign of the currency used in your shop'),
					'name' => 'PS_MAPQP_SIGN',
					'label' => $this->l('Sign'),
				),
				),
					'submit' => array(
					'title' => $this->l('Save'),
				),
			),
		);
	}

	protected function getConfigFormValues()
	{
		return array(
		'PS_MAPQP_SIGN' => Configuration::get('PS_MAPQP_SIGN', null)
		);
	}

	protected function postProcess()
	{
		$form_values = $this->getConfigFormValues();

		foreach (array_keys($form_values) as $key)
			Configuration::updateValue($key, Tools::getValue($key));
		$this->createFile();
	}

	protected function createFile()
	{
		$contenido = Tools::file_get_contents($this->local_path.'/jstemplate.tp');
		$ftosave = str_replace('{*simbolo*}', '\''.Configuration::get('PS_MAPQP_SIGN').'\'', $contenido);
		file_put_contents($this->local_path.'/views/js/front.js', $ftosave);
	}

	public function hookDisplayFooterProduct()
	{
		$this->context->controller->addJS($this->_path.'/views/js/front.js');
	}
}
